@@ -6,7 +6,13 @@ DIR=jdom-JDOM-*
 
 tar xvf $3
 rm $3
-tar -c -J -f $TAR --exclude '*.jar' --exclude '.gitignore' $DIR
+XZ_OPT=--best tar -c -J -f $TAR \
+    --exclude '*.jar' \
+    --exclude '.gitignore' \
+    --exclude 'hamlet.xml' \
+    --exclude 'core/samples/catalog.xml' \
+    --exclude 'core/samples/catalog.xsl' \
+    $DIR
 rm -rf $DIR
 
 # move to directory 'tarballs'
